@@ -251,6 +251,33 @@ SCC = Instruction(
         ]
     )
 
+MVB = Instruction(
+        'MVB',
+        0x1D,
+        [
+            Argument('src', PTR),
+            Argument('dest', PTR),
+        ]
+    )
+
+MVI = Instruction(
+        'MVI',
+        0x1E,
+        [
+            Argument('src', PTR),
+            Argument('dest', PTR),
+        ]
+    )
+
+MVL = Instruction(
+        'MVL',
+        0x1F,
+        [
+            Argument('src', PTR),
+            Argument('dest', PTR),
+        ]
+    )
+
 instructions = {
         0x00: POK,
         0x02: DEL,
@@ -279,4 +306,7 @@ instructions = {
         0x1A: MOV,
         0x1B: SCS,
         0x1C: SCC,
+        0x1D: MVB,
+        0x1E: MVI,
+        0x1F: MVL,
 }
